@@ -1,6 +1,6 @@
 //  -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2011 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2017 Fons Adriaensen <fons@linuxaudio.org>
 //  
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -92,7 +92,7 @@ static int readfile (const char *line, int lnum, const char *cdir)
         fprintf (stderr, "Line %d: Unable to open '%s'.\n", lnum, path);
         return ERR_OTHER;
     } 
-
+    
     if (audio.rate () != (int) fsamp)
     {
         fprintf (stderr, "Line %d: Sample rate (%d) of '%s' does not match.\n",
@@ -106,7 +106,8 @@ static int readfile (const char *line, int lnum, const char *cdir)
 	fprintf (stderr, "Line %d: Channel not available.\n", lnum);
         audio.close ();
         return ERR_OTHER;
-    } 
+    }
+
     if (offset && audio.seek (offset))
     {
 	fprintf (stderr, "Line %d: Can't seek to offset.\n", lnum);
@@ -119,7 +120,6 @@ static int readfile (const char *line, int lnum, const char *cdir)
 	length = size - delay;
    	fprintf (stderr, "Line %d: Data truncated.\n", lnum);
     }
-
     try 
     {
         buff = new float [BSIZE * nchan];
@@ -302,6 +302,20 @@ int config (const char *config)
         {
             if (sstring (q, cdir, 1024) == 0) stat = ERR_PARAM;
         }	
+        else if (! strcmp (p, "/jack/client"))
+	{
+	    if (!jackname [0])
+	    {
+                if (sstring (q, jackname, NAMELEN) == 0) stat = ERR_PARAM;
+	    }
+	}
+        else if (! strcmp (p, "/jack/server"))
+	{
+	    if (!jackserv [0])
+	    {
+                if (sstring (q, jackserv, NAMELEN) == 0) stat = ERR_PARAM;
+	    }
+	}
         else if (! strcmp (p, "/convolver/new"))   stat = convnew (q, lnum);
         else if (! strcmp (p, "/impulse/read"))    stat = readfile (q, lnum, cdir);
         else if (! strcmp (p, "/impulse/dirac"))   stat = impdirac (q, lnum); 
