@@ -1,6 +1,6 @@
 //  -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2011 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2017 Fons Adriaensen <fons@linuxaudio.org>
 //  
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -26,15 +26,18 @@
 #include <zita-convolver.h>
 #include "sstring.h"
 
+#define NAMELEN 64
 
 extern Convproc      *convproc;
-extern unsigned int  latency;
-extern unsigned int  options;
-extern unsigned int  fsamp;
-extern unsigned int  fragm;
-extern unsigned int  ninp;
-extern unsigned int  nout;
-extern unsigned int  size;
+extern char           jackname [NAMELEN];
+extern char           jackserv [NAMELEN];
+extern unsigned int   latency;
+extern unsigned int   options;
+extern unsigned int   fsamp;
+extern unsigned int   fragm;
+extern unsigned int   ninp;
+extern unsigned int   nout;
+extern unsigned int   size;
 
 
 enum { NOERR, ERR_OTHER, ERR_SYNTAX, ERR_PARAM, ERR_ALLOC, ERR_CANTCD, ERR_COMMAND, ERR_NOCONV, ERR_IONUM };
@@ -47,7 +50,7 @@ extern int  outname (const char *line);
 extern void makeports (void);
 
 
-#define MAXSIZE 0x00200000
+#define MAXSIZE 0x00100000
 
 
 #endif
