@@ -1,6 +1,6 @@
 //  -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2021 Fons Adriaensen <fons@linuxaudio.org>
 //  
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -34,9 +34,10 @@
 #endif
 
 
-static const char *clopt = "hvMV";
+static const char *clopt = "hvMVT";
 static bool M_opt = false;
 static bool V_opt = false;
+static bool T_opt = false;
 static bool stop = false;
 
 
@@ -55,12 +56,13 @@ unsigned int   size = 0;
 static void help (void)
 {
     fprintf (stderr, "\nFconvolver %s\n", VERSION);
-    fprintf (stderr, "(C) 2006-2018 Fons Adriaensen  <fons@linuxaudio.org>\n\n");
+    fprintf (stderr, "(C) 2006-2021 Fons Adriaensen  <fons@linuxaudio.org>\n\n");
     fprintf (stderr, "Usage: fconvolver <configuration file> <input file> <output file>\n");
     fprintf (stderr, "Options:\n");
     fprintf (stderr, "  -h                 Display this text\n");
     fprintf (stderr, "  -M                 Use the FFTW_MEASURE option [off]\n");   
     fprintf (stderr, "  -V                 Use vector mode processing [off]\n");   
+    fprintf (stderr, "  -T                 Truncate output to input size [off]\n");   
     exit (1);
 }
 
@@ -85,6 +87,7 @@ static void procoptions (int ac, char *av [], const char *where)
         case 'h' : help (); exit (0);
         case 'M' : M_opt = true; break;
         case 'V' : V_opt = true; break;
+        case 'T' : T_opt = true; break;
         case '?':
             fprintf (stderr, "\n%s\n", where);
             if (optopt != ':' && strchr (clopt, optopt))
@@ -164,7 +167,8 @@ int main (int ac, char *av [])
         return 1;
     } 
 
-    nf = Ainp.size () + size - 1;
+    nf = Ainp.size ();
+    if (! T_opt) nf += size - 1;
     buff = new float [fragm * ((ninp > nout) ? ninp : nout)];
     signal (SIGINT, sigint_handler); 
 
