@@ -85,7 +85,7 @@ void Jclient::init_jack (const char *jname, const char *jserv)
     int                 opts;
 
     opts = JackNoStartServer;
-    if (jserv) opts |= JackServerName;
+    if (*jserv) opts |= JackServerName;
     if ((_jack_client = jack_client_open (jname, (jack_options_t) opts, &stat, jserv)) == 0)
     {
         fprintf (stderr, "Can't connect to JACK\n");
