@@ -1,6 +1,6 @@
 //  -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2014 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
 //  
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -30,22 +30,23 @@
 #include "config.h"
 
 
-#if ZITA_CONVOLVER_MAJOR_VERSION < 3
-#error "This program requires zita-convolver version 3 or higher."
+#if ZITA_CONVOLVER_MAJOR_VERSION < 4
+#error "This program requires zita-convolver version 4 or higher."
 #endif
 
 
-static const char   *clopt = "hvL:MVN:s:";
-static const char   *N_val = "jconvolver";
-static const char   *s_val = 0;
-static unsigned int  L_val = 0;
+static const char   *clopt = "hvL:MVZN:s:";
 static bool          M_opt = false;
 static bool          V_opt = false;
+static bool          Z_opt = false;
 static bool          v_opt = false;
 static bool          stop  = false;
 
 
 Convproc      *convproc = 0;
+Jclient       *jclient = 0;
+char           jackname [NAMELEN];
+char           jackserv [NAMELEN];
 unsigned int   latency = 0;
 unsigned int   options = 0;
 unsigned int   fsamp = 0;
@@ -53,13 +54,12 @@ unsigned int   fragm = 0;
 unsigned int   ninp = 0;
 unsigned int   nout = 0;
 unsigned int   size = 0;
-Jclient       *jclient = 0;
 
 
 static void help (void)
 {
     fprintf (stderr, "\nJconvolver %s\n", VERSION);
-    fprintf (stderr, "(C) 2006-2014 Fons Adriaensen  <fons@linuxaudio.org>\n\n");
+    fprintf (stderr, "(C) 2006-2018 Fons Adriaensen  <fons@linuxaudio.org>\n\n");
     fprintf (stderr, "Usage: jconvolver <options> <config file> {<connect file>}\n");
     fprintf (stderr, "Options:\n");
     fprintf (stderr, "  -h                 Display this text\n");
@@ -67,6 +67,7 @@ static void help (void)
     fprintf (stderr, "  -L <nframes>       Try to compensate <nframes> latency\n");
     fprintf (stderr, "  -M                 Use the FFTW_MEASURE option [off]\n");   
     fprintf (stderr, "  -V                 Use vector mode processing [off]\n");   
+    fprintf (stderr, "  -Z                 Add noise for denormal protection [off]\n");   
     fprintf (stderr, "  -N <name>          Name to use as JACK client [jconvolver]\n");   
     fprintf (stderr, "  -s <server>        Jack server name\n");
     exit (1);
@@ -92,11 +93,12 @@ static void procoptions (int ac, char *av [], const char *where)
 	{
         case 'h' : help (); exit (0);
         case 'v' : v_opt = true; break;
-        case 'L' : L_val = atoi (optarg); break;
+        case 'L' : latency = atoi (optarg); break;
         case 'M' : M_opt = true; break;
         case 'V' : V_opt = true; break;
-        case 'N' : N_val = optarg; break; 
-        case 's' : s_val = optarg; break; 
+        case 'Z' : Z_opt = true; break;
+        case 'N' : strncpy (jackname, optarg, NAMELEN - 1); break;
+        case 's' : strncpy (jackserv, optarg, NAMELEN - 1); break;
         case '?':
             fprintf (stderr, "\n%s\n", where);
             if (optopt != ':' && strchr (clopt, optopt))
@@ -142,39 +144,19 @@ int main (int ac, char *av [])
         perror ("mlockall:");
     }
 
+    memset (jackname, 0, NAMELEN);
+    memset (jackserv, 0, NAMELEN);
     procoptions (ac, av, "On command line:");
     if (ac <= optind) help ();
-
-    convproc = new Convproc;
-    jclient = new Jclient (N_val, s_val, convproc);
-    fsamp = jclient->fsamp ();
-    fragm = jclient->fragm ();
-
-    if ((fragm < Convproc::MINQUANT) || (fragm > Convproc::MAXQUANT))
-    {
-	fprintf (stderr, "Jack period must be in the range %d...%d\n",
-                 Convproc::MINQUANT, Convproc::MAXQUANT);
-	delete jclient;
-	delete convproc;
-	return 1;
-    }
-    if (fragm & (fragm - 1))
-    {
-	fprintf (stderr, "Jack period must be a power of 2\n");
-	delete jclient;
-	delete convproc;
-	return 1;
-    }
-
     if (M_opt) options |= Convproc::OPT_FFTW_MEASURE;
     if (V_opt) options |= Convproc::OPT_VECTOR_MODE;
-    latency = L_val;
     if (config (av [optind]))
     {
 	delete jclient;
 	delete convproc;
         return 1;
     }
+    jclient->denorm_protect (Z_opt);
     if (v_opt) convproc->print ();
 
     makeports ();
